fill_dictionary: Fill in the dictionary file based on the tidy data...

View source: R/setup_dictionary.R

fill_dictionaryR Documentation

Fill in the dictionary file based on the tidy data information

Description

Fill in the dictionary file based on the tidy data information

Usage

fill_dictionary(dict_path, data_dir)

Arguments

dict_path

Path to the dictionary csvfile.

data_dir

Path to the directory of the tidy R data objects. Defaults to data/

Value

A tibble data frame of dataset dictionary with an empty description column to be written.

Examples

## Not run: 
fill_dictionary(dict_path = "data-raw/dictionary.csv", data_dir = "data/")

## End(Not run)


washr documentation built on Sept. 2, 2026, 5:07 p.m.