setup_rawdata: Create the data-raw directory with a data-processing.R...

View source: R/setup_rawdata.R

setup_rawdataR Documentation

Create the data-raw directory with a data-processing.R template

Description

setup_rawdata() creates a directory for raw data and an example script named data_processing.R for importing, processing and exporting the tidy data. The template assumes that the dataset name is the same as the data package name.

Usage

setup_rawdata()

Value

NULL. This function will create a directory "data-raw" under the package directory.

See Also

Before: setup_ci(). Next: setup_dictionary() once the processing script has exported the tidy data with usethis::use_data().

Other setup functions: setup_ci(), setup_dictionary(), setup_roxygen()

Examples

## Not run: 
  setup_rawdata()

## End(Not run)


washr documentation built on Sept. 2, 2026, 5:07 p.m.