View source: R/setup_rawdata.R
| setup_rawdata | R Documentation |
setup_rawdata() creates a directory for raw data and an example script
named data_processing.R for importing, processing and exporting the tidy data.
The template assumes that the dataset name is the same as the data package name.
setup_rawdata()
NULL. This function will create a directory "data-raw" under the package directory.
Before: setup_ci(). Next: setup_dictionary() once the processing script has exported the tidy data with usethis::use_data().
Other setup functions:
setup_ci(),
setup_dictionary(),
setup_roxygen()
## Not run:
setup_rawdata()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.